package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBillsInspectInstanceActivity;

/**
 * 点巡检工单实例节点Mapper接口
 *
 * @author Open Platform
 * @date 2024-01-23
 */
public interface DmsBillsInspectInstanceActivityMapper
{
    /**
     * 查询点巡检工单实例节点
     *
     * @param instanceActivityId 点巡检工单实例节点主键
     * @return 点巡检工单实例节点
     */
    public DmsBillsInspectInstanceActivity selectDmsBillsInspectInstanceActivityByInstanceActivityId(Long instanceActivityId);

    /**
     * 查询点巡检工单实例节点列表
     *
     * @param dmsBillsInspectInstanceActivity 点巡检工单实例节点
     * @return 点巡检工单实例节点集合
     */
    public List<DmsBillsInspectInstanceActivity> selectDmsBillsInspectInstanceActivityList(DmsBillsInspectInstanceActivity dmsBillsInspectInstanceActivity);

    /**
     * 新增点巡检工单实例节点
     *
     * @param dmsBillsInspectInstanceActivity 点巡检工单实例节点
     * @return 结果
     */
    public int insertDmsBillsInspectInstanceActivity(DmsBillsInspectInstanceActivity dmsBillsInspectInstanceActivity);

    /**
     * 修改点巡检工单实例节点
     *
     * @param dmsBillsInspectInstanceActivity 点巡检工单实例节点
     * @return 结果
     */
    public int updateDmsBillsInspectInstanceActivity(DmsBillsInspectInstanceActivity dmsBillsInspectInstanceActivity);

    /**
     * 删除点巡检工单实例节点
     *
     * @param instanceActivityId 点巡检工单实例节点主键
     * @return 结果
     */
    public int deleteDmsBillsInspectInstanceActivityByInstanceActivityId(Long instanceActivityId);

    /**
     * 批量删除点巡检工单实例节点
     *
     * @param instanceActivityIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBillsInspectInstanceActivityByInstanceActivityIds(Long[] instanceActivityIds);

    Long[] selectUserIdByDmsBillsInspectInstanceActivityId(Long lubeInstanceId);


}
